Class: TmdbApiClient::AccountFavoriteTvResponseResultsItem
- Inherits:
-
Object
- Object
- TmdbApiClient::AccountFavoriteTvResponseResultsItem
- Defined in:
- lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
- #adult ⇒ Boolean readonly
- #backdrop_path ⇒ String readonly
- #first_air_date ⇒ String readonly
- #genre_ids ⇒ Array<Integer> readonly
- #id ⇒ Integer readonly
- #name ⇒ String readonly
- #origin_country ⇒ Array<String> readonly
- #original_language ⇒ String readonly
- #original_name ⇒ String readonly
- #overview ⇒ String readonly
- #popularity ⇒ Float readonly
- #poster_path ⇒ String readonly
- #vote_average ⇒ Float readonly
- #vote_count ⇒ Integer readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TmdbApiClient::AccountFavoriteTvResponseResultsItem
Deserialize a JSON object to an instance of AccountFavoriteTvResponseResultsItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(adult: OMIT, backdrop_path: OMIT, genre_ids: OMIT, id: OMIT, origin_country: OMIT, original_language: OMIT, original_name: OMIT, overview: OMIT, popularity: OMIT, poster_path: OMIT, first_air_date: OMIT, name: OMIT, vote_average: OMIT, vote_count: OMIT, additional_properties: nil) ⇒ TmdbApiClient::AccountFavoriteTvResponseResultsItem constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of AccountFavoriteTvResponseResultsItem to a JSON object.
Constructor Details
#initialize(adult: OMIT, backdrop_path: OMIT, genre_ids: OMIT, id: OMIT, origin_country: OMIT, original_language: OMIT, original_name: OMIT, overview: OMIT, popularity: OMIT, poster_path: OMIT, first_air_date: OMIT, name: OMIT, vote_average: OMIT, vote_count: OMIT, additional_properties: nil) ⇒ TmdbApiClient::AccountFavoriteTvResponseResultsItem
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 60 def initialize(adult: OMIT, backdrop_path: OMIT, genre_ids: OMIT, id: OMIT, origin_country: OMIT, original_language: OMIT, original_name: OMIT, overview: OMIT, popularity: OMIT, poster_path: OMIT, first_air_date: OMIT, name: OMIT, vote_average: OMIT, vote_count: OMIT, additional_properties: nil) @adult = adult if adult != OMIT @backdrop_path = backdrop_path if backdrop_path != OMIT @genre_ids = genre_ids if genre_ids != OMIT @id = id if id != OMIT @origin_country = origin_country if origin_country != OMIT @original_language = original_language if original_language != OMIT @original_name = original_name if original_name != OMIT @overview = overview if overview != OMIT @popularity = popularity if popularity != OMIT @poster_path = poster_path if poster_path != OMIT @first_air_date = first_air_date if first_air_date != OMIT @name = name if name != OMIT @vote_average = vote_average if vote_average != OMIT @vote_count = vote_count if vote_count != OMIT @additional_properties = additional_properties @_field_set = { "adult": adult, "backdrop_path": backdrop_path, "genre_ids": genre_ids, "id": id, "origin_country": origin_country, "original_language": original_language, "original_name": original_name, "overview": overview, "popularity": popularity, "poster_path": poster_path, "first_air_date": first_air_date, "name": name, "vote_average": vote_average, "vote_count": vote_count }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
37 38 39 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 37 def additional_properties @additional_properties end |
#adult ⇒ Boolean (readonly)
9 10 11 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 9 def adult @adult end |
#backdrop_path ⇒ String (readonly)
11 12 13 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 11 def backdrop_path @backdrop_path end |
#first_air_date ⇒ String (readonly)
29 30 31 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 29 def first_air_date @first_air_date end |
#genre_ids ⇒ Array<Integer> (readonly)
13 14 15 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 13 def genre_ids @genre_ids end |
#id ⇒ Integer (readonly)
15 16 17 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 15 def id @id end |
#name ⇒ String (readonly)
31 32 33 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 31 def name @name end |
#origin_country ⇒ Array<String> (readonly)
17 18 19 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 17 def origin_country @origin_country end |
#original_language ⇒ String (readonly)
19 20 21 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 19 def original_language @original_language end |
#original_name ⇒ String (readonly)
21 22 23 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 21 def original_name @original_name end |
#overview ⇒ String (readonly)
23 24 25 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 23 def overview @overview end |
#popularity ⇒ Float (readonly)
25 26 27 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 25 def popularity @popularity end |
#poster_path ⇒ String (readonly)
27 28 29 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 27 def poster_path @poster_path end |
#vote_average ⇒ Float (readonly)
33 34 35 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 33 def vote_average @vote_average end |
#vote_count ⇒ Integer (readonly)
35 36 37 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 35 def vote_count @vote_count end |
Class Method Details
.from_json(json_object:) ⇒ TmdbApiClient::AccountFavoriteTvResponseResultsItem
Deserialize a JSON object to an instance of AccountFavoriteTvResponseResultsItem
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 101 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) adult = parsed_json["adult"] backdrop_path = parsed_json["backdrop_path"] genre_ids = parsed_json["genre_ids"] id = parsed_json["id"] origin_country = parsed_json["origin_country"] original_language = parsed_json["original_language"] original_name = parsed_json["original_name"] overview = parsed_json["overview"] popularity = parsed_json["popularity"] poster_path = parsed_json["poster_path"] first_air_date = parsed_json["first_air_date"] name = parsed_json["name"] vote_average = parsed_json["vote_average"] vote_count = parsed_json["vote_count"] new( adult: adult, backdrop_path: backdrop_path, genre_ids: genre_ids, id: id, origin_country: origin_country, original_language: original_language, original_name: original_name, overview: overview, popularity: popularity, poster_path: poster_path, first_air_date: first_air_date, name: name, vote_average: vote_average, vote_count: vote_count, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 150 def self.validate_raw(obj:) obj.adult&.is_a?(Boolean) != false || raise("Passed value for field obj.adult is not the expected type, validation failed.") obj.backdrop_path&.is_a?(String) != false || raise("Passed value for field obj.backdrop_path is not the expected type, validation failed.") obj.genre_ids&.is_a?(Array) != false || raise("Passed value for field obj.genre_ids is not the expected type, validation failed.") obj.id&.is_a?(Integer) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.origin_country&.is_a?(Array) != false || raise("Passed value for field obj.origin_country is not the expected type, validation failed.") obj.original_language&.is_a?(String) != false || raise("Passed value for field obj.original_language is not the expected type, validation failed.") obj.original_name&.is_a?(String) != false || raise("Passed value for field obj.original_name is not the expected type, validation failed.") obj.overview&.is_a?(String) != false || raise("Passed value for field obj.overview is not the expected type, validation failed.") obj.popularity&.is_a?(Float) != false || raise("Passed value for field obj.popularity is not the expected type, validation failed.") obj.poster_path&.is_a?(String) != false || raise("Passed value for field obj.poster_path is not the expected type, validation failed.") obj.first_air_date&.is_a?(String) != false || raise("Passed value for field obj.first_air_date is not the expected type, validation failed.") obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.vote_average&.is_a?(Float) != false || raise("Passed value for field obj.vote_average is not the expected type, validation failed.") obj.vote_count&.is_a?(Integer) != false || raise("Passed value for field obj.vote_count is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of AccountFavoriteTvResponseResultsItem to a JSON object
140 141 142 |
# File 'lib/tmdb_ryanstep/types/account_favorite_tv_response_results_item.rb', line 140 def to_json(*_args) @_field_set&.to_json end |