Class: TmdbApiClient::AccountRatedMoviesResponseResultsItem
- Inherits:
-
Object
- Object
- TmdbApiClient::AccountRatedMoviesResponseResultsItem
- Defined in:
- lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
- #account_rating ⇒ TmdbApiClient::AccountRatedMoviesResponseResultsItemAccountRating readonly
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
- #adult ⇒ Boolean readonly
- #backdrop_path ⇒ String readonly
- #genre_ids ⇒ Array<Integer> readonly
- #id ⇒ Integer readonly
- #original_language ⇒ String readonly
- #original_title ⇒ String readonly
- #overview ⇒ String readonly
- #popularity ⇒ Float readonly
- #poster_path ⇒ String readonly
- #release_date ⇒ String readonly
- #title ⇒ String readonly
- #video ⇒ Boolean readonly
- #vote_average ⇒ Float readonly
- #vote_count ⇒ Integer readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TmdbApiClient::AccountRatedMoviesResponseResultsItem
Deserialize a JSON object to an instance of AccountRatedMoviesResponseResultsItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(adult: OMIT, backdrop_path: OMIT, genre_ids: OMIT, id: OMIT, original_language: OMIT, original_title: OMIT, overview: OMIT, popularity: OMIT, poster_path: OMIT, release_date: OMIT, title: OMIT, video: OMIT, vote_average: OMIT, vote_count: OMIT, account_rating: OMIT, additional_properties: nil) ⇒ TmdbApiClient::AccountRatedMoviesResponseResultsItem constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of AccountRatedMoviesResponseResultsItem to a JSON object.
Constructor Details
#initialize(adult: OMIT, backdrop_path: OMIT, genre_ids: OMIT, id: OMIT, original_language: OMIT, original_title: OMIT, overview: OMIT, popularity: OMIT, poster_path: OMIT, release_date: OMIT, title: OMIT, video: OMIT, vote_average: OMIT, vote_count: OMIT, account_rating: OMIT, additional_properties: nil) ⇒ TmdbApiClient::AccountRatedMoviesResponseResultsItem
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 64 def initialize(adult: OMIT, backdrop_path: OMIT, genre_ids: OMIT, id: OMIT, original_language: OMIT, original_title: OMIT, overview: OMIT, popularity: OMIT, poster_path: OMIT, release_date: OMIT, title: OMIT, video: OMIT, vote_average: OMIT, vote_count: OMIT, account_rating: OMIT, additional_properties: nil) @adult = adult if adult != OMIT @backdrop_path = backdrop_path if backdrop_path != OMIT @genre_ids = genre_ids if genre_ids != OMIT @id = id if id != OMIT @original_language = original_language if original_language != OMIT @original_title = original_title if original_title != OMIT @overview = overview if overview != OMIT @popularity = popularity if popularity != OMIT @poster_path = poster_path if poster_path != OMIT @release_date = release_date if release_date != OMIT @title = title if title != OMIT @video = video if video != OMIT @vote_average = vote_average if vote_average != OMIT @vote_count = vote_count if vote_count != OMIT = if != OMIT @additional_properties = additional_properties @_field_set = { "adult": adult, "backdrop_path": backdrop_path, "genre_ids": genre_ids, "id": id, "original_language": original_language, "original_title": original_title, "overview": overview, "popularity": popularity, "poster_path": poster_path, "release_date": release_date, "title": title, "video": video, "vote_average": vote_average, "vote_count": vote_count, "account_rating": }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account_rating ⇒ TmdbApiClient::AccountRatedMoviesResponseResultsItemAccountRating (readonly)
38 39 40 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 38 def end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
40 41 42 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 40 def additional_properties @additional_properties end |
#adult ⇒ Boolean (readonly)
10 11 12 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 10 def adult @adult end |
#backdrop_path ⇒ String (readonly)
12 13 14 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 12 def backdrop_path @backdrop_path end |
#genre_ids ⇒ Array<Integer> (readonly)
14 15 16 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 14 def genre_ids @genre_ids end |
#id ⇒ Integer (readonly)
16 17 18 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 16 def id @id end |
#original_language ⇒ String (readonly)
18 19 20 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 18 def original_language @original_language end |
#original_title ⇒ String (readonly)
20 21 22 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 20 def original_title @original_title end |
#overview ⇒ String (readonly)
22 23 24 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 22 def overview @overview end |
#popularity ⇒ Float (readonly)
24 25 26 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 24 def popularity @popularity end |
#poster_path ⇒ String (readonly)
26 27 28 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 26 def poster_path @poster_path end |
#release_date ⇒ String (readonly)
28 29 30 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 28 def release_date @release_date end |
#title ⇒ String (readonly)
30 31 32 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 30 def title @title end |
#video ⇒ Boolean (readonly)
32 33 34 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 32 def video @video end |
#vote_average ⇒ Float (readonly)
34 35 36 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 34 def vote_average @vote_average end |
#vote_count ⇒ Integer (readonly)
36 37 38 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 36 def vote_count @vote_count end |
Class Method Details
.from_json(json_object:) ⇒ TmdbApiClient::AccountRatedMoviesResponseResultsItem
Deserialize a JSON object to an instance of AccountRatedMoviesResponseResultsItem
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 108 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) adult = parsed_json["adult"] backdrop_path = parsed_json["backdrop_path"] genre_ids = parsed_json["genre_ids"] id = parsed_json["id"] original_language = parsed_json["original_language"] original_title = parsed_json["original_title"] overview = parsed_json["overview"] popularity = parsed_json["popularity"] poster_path = parsed_json["poster_path"] release_date = parsed_json["release_date"] title = parsed_json["title"] video = parsed_json["video"] vote_average = parsed_json["vote_average"] vote_count = parsed_json["vote_count"] if parsed_json["account_rating"].nil? = nil else = parsed_json["account_rating"].to_json = TmdbApiClient::AccountRatedMoviesResponseResultsItemAccountRating.from_json(json_object: ) end new( adult: adult, backdrop_path: backdrop_path, genre_ids: genre_ids, id: id, original_language: original_language, original_title: original_title, overview: overview, popularity: popularity, poster_path: poster_path, release_date: release_date, title: title, video: video, vote_average: vote_average, vote_count: vote_count, account_rating: , additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 164 def self.validate_raw(obj:) obj.adult&.is_a?(Boolean) != false || raise("Passed value for field obj.adult is not the expected type, validation failed.") obj.backdrop_path&.is_a?(String) != false || raise("Passed value for field obj.backdrop_path is not the expected type, validation failed.") obj.genre_ids&.is_a?(Array) != false || raise("Passed value for field obj.genre_ids is not the expected type, validation failed.") obj.id&.is_a?(Integer) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.original_language&.is_a?(String) != false || raise("Passed value for field obj.original_language is not the expected type, validation failed.") obj.original_title&.is_a?(String) != false || raise("Passed value for field obj.original_title is not the expected type, validation failed.") obj.overview&.is_a?(String) != false || raise("Passed value for field obj.overview is not the expected type, validation failed.") obj.popularity&.is_a?(Float) != false || raise("Passed value for field obj.popularity is not the expected type, validation failed.") obj.poster_path&.is_a?(String) != false || raise("Passed value for field obj.poster_path is not the expected type, validation failed.") obj.release_date&.is_a?(String) != false || raise("Passed value for field obj.release_date is not the expected type, validation failed.") obj.title&.is_a?(String) != false || raise("Passed value for field obj.title is not the expected type, validation failed.") obj.video&.is_a?(Boolean) != false || raise("Passed value for field obj.video is not the expected type, validation failed.") obj.vote_average&.is_a?(Float) != false || raise("Passed value for field obj.vote_average is not the expected type, validation failed.") obj.vote_count&.is_a?(Integer) != false || raise("Passed value for field obj.vote_count is not the expected type, validation failed.") obj..nil? || TmdbApiClient::AccountRatedMoviesResponseResultsItemAccountRating.validate_raw(obj: obj.) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of AccountRatedMoviesResponseResultsItem to a JSON object
154 155 156 |
# File 'lib/tmdb_ryanstep/types/account_rated_movies_response_results_item.rb', line 154 def to_json(*_args) @_field_set&.to_json end |